@@ -20,7 +20,7 @@ Shows their status graphically.
 """
 
 __author__ = 'Scott Kirkwood (scott+keymon@forusers.com)'
-__version__ = '1.6'
+__version__ = '1.6.2'
 
 import logging
 import pygtk
@@ -289,6 +289,9 @@ class KeyMon:
         self.pixbufs, 'META_EMPTY', self.enabled['META'])
     self.alt_image = two_state_image.TwoStateImage(
         self.pixbufs, 'ALT_EMPTY', self.enabled['ALT'])
+    self.create_buttons()
+
+  def create_buttons(self):
     self.buttons = [self.mouse_image, self.shift_image, self.ctrl_image,
         self.meta_image, self.alt_image]
     for _ in range(self.options.old_keys):
@@ -296,6 +299,8 @@ class KeyMon:
       self.buttons.append(key_image)
     self.key_image = two_state_image.TwoStateImage(self.pixbufs, 'KEY_EMPTY')
     self.buttons.append(self.key_image)
+    for but in self.buttons:
+      but.timeout_secs = self.options.fade_timeout
 
   def layout_boxes(self):
     for child in self.hbox.get_children():
@@ -323,7 +328,7 @@ class KeyMon:
     self.hbox.pack_start(self.alt_image, False, False, 0)
 
     prev_key_image = None
-    for key_image in self.buttons[self.options.old_keys - 1:-2]:
+    for key_image in self.buttons[-(self.options.old_keys + 1):-1]:
       key_image.hide()
       #key_image.timeout_secs = 0.5
       key_image.defer_to = prev_key_image
@@ -526,6 +531,7 @@ class KeyMon:
       elif value == 1 and n_image:
         code = self.btns[n_image | n_code]
       self._handle_event(self.mouse_image, code, value)
+
     if self.options.visible_click:
       if value == 1:
         self.mouse_indicator_win.center_on_cursor()
@@ -612,6 +618,8 @@ class KeyMon:
         self.options.ctrl)
     self._toggle_a_key(self.alt_image, 'ALT',
         self.options.alt)
+    self.create_buttons()
+    self.layout_boxes()
     if self.options.visible_click:
       self.mouse_indicator_win.fade_away()
     self.window.set_decorated(self.options.decorated)
@@ -619,6 +627,7 @@ class KeyMon:
     self.pixbufs.reset_all(self.name_fnames, self.options.scale)
     for but in self.buttons:
       but.reset_image()
+      but.timeout_secs = self.options.fade_timeout
 
     # all this to get it to resize smaller
     x, y = self.window.get_position()
@@ -677,6 +686,11 @@ def create_options():
                   ini_group='ui', ini_name='scale',
                   help=_('Scale the dialog. ex. 2.0 is 2 times larger, 0.5 is '
                          'half the size. Defaults to %default'))
+  opts.add_option(opt_long='--fade-timeout', dest='fade_timeout',
+                  type='float', default=0.5,
+                  ini_group='ui', ini_name='fade_timeout',
+                  help=_('Timeout before activated buttons fadeout. '
+                         'Defaults to %default'))
   opts.add_option(opt_long='--decorated', dest='decorated', type='bool',
                   ini_group='ui', ini_name='decorated',
                   default=False,
